# Kata Anagrams

This is a python library to solve [Kata Anagram](http://codekata.com/kata/kata06-anagrams/).

## Set Up
Should have Python version greater than or equal 3.7.

Then, clone the repository and now you should have installed the library.

## Run Tests
Go to the ```tests``` folder. Then, open the file you want to run test and run by the following command:
```bash
$ py test/<file_name>.py
```

Example:
```bash
$ py test/test_anagrams.py
```
